@@ -71,6 +71,8 @@ diat_des <- function(resultLoad){
   #removes NA from taxaIn
   taxaIn[is.na(taxaIn)] <- 0
 
+  #removes the Acronym column
+
   #gets the column named "new_species", everything before that is a sample
   lastcol <- which(colnames(taxaIn)=="new_species")
 
@@ -102,12 +104,14 @@ diat_des <- function(resultLoad){
   #######--------DES INDEX: END--------############
   #PRECISION
   resultsPath <- resultLoad[[4]]
-  precisionmatrix <- read.csv(paste(resultsPath,"\\Precision.csv", sep=""))
+  # precisionmatrix <- read.csv(paste(resultsPath,"\\Precision.csv", sep=""))
+  precisionmatrix <- read.csv(file.path(resultsPath, "Precision.csv"))
   precisionmatrix <- cbind(precisionmatrix, des.results$Precision)
   precisionmatrix <- precisionmatrix[-(1:which(colnames(precisionmatrix)=="Sample")-1)]
 
   names(precisionmatrix)[names(precisionmatrix)=="des.results$Precision"] <- "DES"
-  write.csv(precisionmatrix, paste(resultsPath,"\\Precision.csv", sep=""))
+  #write.csv(precisionmatrix, paste(resultsPath,"\\Precision.csv", sep=""))
+  write.csv(precisionmatrix, file.path(resultsPath, "Precision.csv"))
   #END PRECISION
 
 
@@ -115,7 +119,8 @@ diat_des <- function(resultLoad){
   #TAXA INCLUSION
   #taxa with acronyms
   taxaIncluded <- taxaIn$species[which(taxaIn$des_s > 0)]
-  inclusionmatrix <- read.csv(paste(resultsPath,"\\Taxa included.csv", sep=""))
+  #inclusionmatrix <- read.csv(paste(resultsPath,"\\Taxa included.csv", sep=""))
+  inclusionmatrix <- read.csv(file.path(resultsPath, "Taxa included.csv"))
   colnamesInclusionMatrix <- c(colnames(inclusionmatrix), "DES")
   #creates a new data matrix to append the existing Taxa Included file
   newinclusionmatrix <- as.data.frame(matrix(nrow=max(length(taxaIncluded), nrow(inclusionmatrix)), ncol=ncol(inclusionmatrix)+1))
@@ -130,11 +135,14 @@ diat_des <- function(resultLoad){
   inclusionmatrix <- newinclusionmatrix
   colnames(inclusionmatrix) <- colnamesInclusionMatrix
   inclusionmatrix <- inclusionmatrix[-(1:which(colnames(inclusionmatrix)=="Eco.Morpho")-1)]
-  write.csv(inclusionmatrix, paste(resultsPath,"\\Taxa included.csv", sep=""))
+  #write.csv(inclusionmatrix, paste(resultsPath,"\\Taxa included.csv", sep=""))
+  write.csv(inclusionmatrix, file.path(resultsPath,"Taxa included.csv"))
+
   #END TAXA INCLUSION
   #EXCLUDED TAXA
   taxaExcluded <- taxaIn[!('%in%'(taxaIn$species,taxaIncluded)),"species"]
-  exclusionmatrix <- read.csv(paste(resultsPath,"\\Taxa excluded.csv", sep=""))
+  #exclusionmatrix <- read.csv(paste(resultsPath,"\\Taxa excluded.csv", sep=""))
+  exclusionmatrix <- read.csv(file.path(resultsPath, "Taxa excluded.csv"))
   #creates a new data matrix to append the existing Taxa Included file
   newexclusionmatrix <- as.data.frame(matrix(nrow=max(length(taxaExcluded), nrow(exclusionmatrix)), ncol=ncol(exclusionmatrix)+1))
   for (i in 1:ncol(exclusionmatrix)){
@@ -148,7 +156,8 @@ diat_des <- function(resultLoad){
   exclusionmatrix <- newexclusionmatrix
   colnames(exclusionmatrix) <- colnamesInclusionMatrix
   exclusionmatrix <- exclusionmatrix[-(1:which(colnames(exclusionmatrix)=="Eco.Morpho")-1)]
-  write.csv(exclusionmatrix, paste(resultsPath,"\\Taxa excluded.csv", sep=""))
+  #write.csv(exclusionmatrix, paste(resultsPath,"\\Taxa excluded.csv", sep=""))
+  write.csv(exclusionmatrix, file.path(resultsPath,"Taxa excluded.csv"))
   #END EXCLUDED TAXA
 
   rownames(des.results) <- resultLoad[[3]]
