@@ -99,17 +99,20 @@ diat_idap <- function(resultLoad){
   #######--------IDAP INDEX: END--------############
   #PRECISION
   resultsPath <- resultLoad[[4]]
-  precisionmatrix <- read.csv(paste(resultsPath,"\\Precision.csv", sep=""))
+  #precisionmatrix <- read.csv(paste(resultsPath,"\\Precision.csv", sep=""))
+  precisionmatrix <- read.csv(file.path(resultsPath, "Precision.csv"))
   precisionmatrix <- cbind(precisionmatrix, idap.results$Precision)
   precisionmatrix <- precisionmatrix[-(1:which(colnames(precisionmatrix)=="Sample")-1)]
   names(precisionmatrix)[names(precisionmatrix)=="idap.results$Precision"] <- "IDAP"
-  write.csv(precisionmatrix, paste(resultsPath,"\\Precision.csv", sep=""))
+  #write.csv(precisionmatrix, paste(resultsPath,"\\Precision.csv", sep=""))
+  write.csv(precisionmatrix, file.path(resultsPath, "Precision.csv"))
   #END PRECISION
 
   #TAXA INCLUSION
   #taxa with acronyms
   taxaIncluded <- taxaIn$new_species[which(taxaIn$idap_s > 0)]
-  inclusionmatrix <- read.csv(paste(resultsPath,"\\Taxa included.csv", sep=""))
+  #inclusionmatrix <- read.csv(paste(resultsPath,"\\Taxa included.csv"))
+  inclusionmatrix <- read.csv(file.path(resultsPath, "Taxa included.csv"))
   colnamesInclusionMatrix <- c(colnames(inclusionmatrix), "IDAP")
   #creates a new data matrix to append the existing Taxa Included file
   newinclusionmatrix <- as.data.frame(matrix(nrow=max(length(taxaIncluded), nrow(inclusionmatrix)), ncol=ncol(inclusionmatrix)+1))
@@ -124,11 +127,13 @@ diat_idap <- function(resultLoad){
   inclusionmatrix <- newinclusionmatrix
   colnames(inclusionmatrix) <- colnamesInclusionMatrix
   inclusionmatrix <- inclusionmatrix[-(1:which(colnames(inclusionmatrix)=="Eco.Morpho")-1)]
-  write.csv(inclusionmatrix, paste(resultsPath,"\\Taxa included.csv", sep=""))
+  #write.csv(inclusionmatrix, paste(resultsPath,"\\Taxa included.csv", sep=""))
+  write.csv(inclusionmatrix, file.path(resultsPath,"Taxa included.csv"))
   #END TAXA INCLUSION
   #EXCLUDED TAXA
   taxaExcluded <- taxaIn[!('%in%'(taxaIn$new_species,taxaIncluded)),"new_species"]
-  exclusionmatrix <- read.csv(paste(resultsPath,"\\Taxa excluded.csv", sep=""))
+  #exclusionmatrix <- read.csv(paste(resultsPath,"\\Taxa excluded.csv", sep=""))
+  exclusionmatrix <- read.csv(file.path(resultsPath, "Taxa excluded.csv"))
   #creates a new data matrix to append the existing Taxa Included file
   newexclusionmatrix <- as.data.frame(matrix(nrow=max(length(taxaExcluded), nrow(exclusionmatrix)), ncol=ncol(exclusionmatrix)+1))
   for (i in 1:ncol(exclusionmatrix)){
@@ -142,7 +147,8 @@ diat_idap <- function(resultLoad){
   exclusionmatrix <- newexclusionmatrix
   colnames(exclusionmatrix) <- colnamesInclusionMatrix
   exclusionmatrix <- exclusionmatrix[-(1:which(colnames(exclusionmatrix)=="Eco.Morpho")-1)]
-  write.csv(exclusionmatrix, paste(resultsPath,"\\Taxa excluded.csv", sep=""))
+  #write.csv(exclusionmatrix, paste(resultsPath,"\\Taxa excluded.csv", sep=""))
+  write.csv(exclusionmatrix, file.path(resultsPath,"Taxa excluded.csv"))
   #END EXCLUDED TAXA
 
   rownames(idap.results) <- resultLoad[[3]]
